<?php
/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return array (
  2162 => 'Ooredoo',
  21640 => 'Tunisie Telecom',
  21641 => 'Tunisie Telecom',
  21642 => 'Tunisie Telecom',
  21643 => 'Lyca Mobile',
  21644 => 'Tunisie Telecom',
  21645 => 'Watany Ettisalat',
  21646 => 'Ooredoo',
  21647 => 'Tunisie Telecom',
  2165 => 'Orange',
  2169 => 'Tunisie Telecom',
);
